# ################################################################################
# Title: HATI excecute command script
# Project: HATI
#
# File       : excecute_command.sh
#
# Description: This script is used to execute a command in the HATI shell through
# the JTAG to AXI module.
# 
#
# Licence and Copyright:
# Copyright (c) 2022 Safran Trusted 4D (https://www.safran-group.com/companies/safran-trusted-4d)
# 
# You might use, distribute and modify this code and its resulting
# binary form under the terms of the LICENSE.txt provided within the
# repository or project.
#
# If you have not received a copy of the LICENSE.txt along with
# this file please write to info<DOT>spain<AT>orolia<DOT>com and consider that
# this file can not be copied and/or distributed in any forms.
# ################################################################################


#!/bin/bash

XVC_MODE="xvc_no"
ip_and_port="none"
PRINT_OBSOLETE=0

usage() { echo -e "\tUsage: $0 -c <command> -a <0x0ADDRESS> -r <IP:port> -v -o\n" 1>&2; exit 1; }

# Vivado arguments for no vervose and batch mode:
VIVADO_ARGS="-notrace -quiet -mode batch"

# Get argument values
while getopts ":c:a:r:v:o" opt; do
    case "${opt}" in
        c)
            command=${OPTARG}
            ;;
        a)
            hati_addr=${OPTARG}
            ;;
        r)
            ip_and_port=${OPTARG}
            ;;
        v)
            XVC_MODE="xvc_yes"
            ;;
        o)
            PRINT_OBSOLETE=1
            ;;
        *)
            usage
            ;;
    esac
done

# Check if mandatory arguments are provided
if [ -z "${command}" ] || [ -z "${hati_addr}" ] ; then
    usage
fi

# Select the HATI address
hati_base_addr=${hati_addr}

# Check if mandatory arguments are provided
if test "$XVC_MODE" == "xvc_yes" && test "$ip_and_port" == "none"; then
    echo -e "\nIf you use the -v option, you must specify an IP and port with the -r argument too.\n"
    usage
fi

echo -e "\nExecuting command \e[34m${command}\e[39m at address \e[34m${hati_base_addr}...\e[39m\n\n"

# Run the .tcl command
vivado ${VIVADO_ARGS} -source ./tcl_libs/execute_command.tcl -tclargs "${command}" ${hati_base_addr} ${ip_and_port} ${XVC_MODE} ${PRINT_OBSOLETE}

# Delete extra files
rm -rf vivado*
rm -rf .Xil
rm -rf webtalk*
