# ################################################################################
# Title: HATI monitor main
# Project: HATI
#
# File       : main.tcl
#
# Licence and Copyright:
# Copyright (c) 2022 Safran Trusted 4D (https://www.safran-group.com/companies/safran-trusted-4d)
#
# You might use, distribute and modify this code and its resulting
# binary form under the terms of the LICENSE.txt provided within the
# repository or project.
#
# If you have not received a copy of the LICENSE.txt along with
# this file please write to info<DOT>spain<AT>orolia<DOT>com and consider that
# this file can not be copied and/or distributed in any forms.
# ################################################################################

# Source each the monitor module.
source ./tcl_libs/monitor.tcl; list
# Source all the hardware utility functions.
source ./tcl_libs/hwutils.tcl; list

set default_mode "lite"
set default_addr 0x1000000

set address     [lindex $argv 3]
set ip_and_port [lindex $argv 4]
set xvc_mode    [lindex $argv 5]


if { ${argc} > 0 } {
    if { "-addr" in ${argv} } {
        set addr_idx [lsearch ${argv} "-addr"]
        set ::hati_addr [lindex ${argv} [expr ${addr_idx} + 1]]
    } else {
        set ::hati_addr ${default_addr}
    }

    if { "-mode" in ${argv} } {
        set mode_idx [lsearch ${argv} "-mode"]
        set mode [lindex ${argv} [expr ${mode_idx} + 1]]
    } else {
        set mode ${default_mode}
    }

} else {
    set mode ${default_mode}
    set ::hati_addr ${default_addr}
    set xvc ${default_xvc}
}

# Open the vivado hardware manager and the FPGA.
connects_to_remote_device $ip_and_port $xvc_mode
open_hardware $ip_and_port

# Runs the monitor expert command.
if { ${mode} == "lite" } {
    monitor_lite
} elseif { ${mode} == "expert" } {
    monitor_expert
} elseif { ${mode} == "getlink" } {
    monitor_getlink
} elseif { ${mode} == "gettf" } {
    monitor_gettf
} else {
    puts "-mode (${mode}) is not a valid mode, <lite> by default"
    monitor_lite
}

# Closes hardware
close_hardware
