# ################################################################################
# Title: HATI uart receive command
# Project: HATI
#
# File       : uart_receive_command.tcl
#
# Licence and Copyright:
# Copyright (c) 2022 Safran Trusted 4D (https://www.safran-group.com/companies/safran-trusted-4d)
#
# You might use, distribute and modify this code and its resulting
# binary form under the terms of the LICENSE.txt provided within the
# repository or project.
#
# If you have not received a copy of the LICENSE.txt along with
# this file please write to info<DOT>spain<AT>orolia<DOT>com and consider that
# this file can not be copied and/or distributed in any forms.
# ################################################################################

set TX_REG 0x0045510
set RX_REG 0x0045514

set eof_char_number 0
set eof_number 0
set retries 0

proc print_character { char print } {

    global eof_number
    global eof_char_number

    if {$print=="print"} {
        puts -nonewline $char
    }

}

proc uart_receive_command { base_addr print {quiet 0} } {

    global TX_REG
    global RX_REG
    global retries

    set read_string ""

    set uart_addr [expr $RX_REG + $base_addr]

    set uart_addr_hex 0x[format %X $uart_addr]

    # Create the read transaction
    create_hw_axi_txn read_rx_reg [get_hw_axis hw_axi_1] -address $uart_addr_hex -type read -force -len 1 -quiet

    while {1==1} {
        # Excecute the read transaction
        run_hw_axi read_rx_reg -quiet
        # Get the occupation characters:
        # report_hw_axi_txn read_rx_reg
        # 1025514  000fff1b
        set result_hex [string range [report_hw_axi_txn read_rx_reg] 13 15]
        scan $result_hex %x result
        # The FIFO occupation is located in 9 to 24 bits, so we shift 1 bit to the right
        set result [expr $result >> 1]

        if {$result == 0} {
            if {$retries == 10} {
                return ${read_string}
            } else {
                after 100
                incr retries
            }
        }

        set index 16

        # Print the two characters of the fist report_hw_axi_txn line
        set data_read_hex [string range [report_hw_axi_txn read_rx_reg] $index [incr index]]
        
        if { ${quiet} == 0 } {
            scan $data_read_hex %x data_read
            set character [binary format c* $data_read]
            print_character [binary format c* $data_read] $print
        }

    }
}
