# ################################################################################
# Title: HATI uart send command
# Project: HATI
#
# File       : uart_send_command.tcl
#
# Licence and Copyright:
# Copyright (c) 2022 Safran Trusted 4D (https://www.safran-group.com/companies/safran-trusted-4d)
#
# You might use, distribute and modify this code and its resulting
# binary form under the terms of the LICENSE.txt provided within the
# repository or project.
#
# If you have not received a copy of the LICENSE.txt along with
# this file please write to info<DOT>spain<AT>orolia<DOT>com and consider that
# this file can not be copied and/or distributed in any forms.
# ################################################################################

set TX_REG 0x0045510
set RX_REG 0x0045514

set hex_header 0x
set padding 000000


proc send_command { command base_addr } {

    global TX_REG
    global RX_REG
    global hex_header
    global padding
    
    # puts $base_addr
    # puts $TX_REG

    set uart_addr [expr $TX_REG + $base_addr]

    set uart_addr_hex 0x[format %X $uart_addr]

    # puts $uart_addr_hex

    create_hw_axi_txn write_enter [get_hw_axis hw_axi_1] -address $uart_addr_hex -data 0x0000000D -type write -force -quiet
    create_hw_axi_txn write_esc [get_hw_axis hw_axi_1] -address $uart_addr_hex -data 0x0000001B -type write -force -quiet

    run_hw_axi write_esc    -quiet
    run_hw_axi write_enter  -quiet
    run_hw_axi write_enter  -quiet
    run_hw_axi write_enter  -quiet
    run_hw_axi write_enter  -quiet

    # Get the size of the introduced command
    set string_size [string length $command]

    set string_index 0

    # Create the read transaction
    create_hw_axi_txn read_tx_reg [get_hw_axis hw_axi_1] -address $uart_addr_hex -type read -force -quiet

    # Interate from 0 to command size
    while {$string_index != $string_size} {

        # Excecute the read transaction
        run_hw_axi read_tx_reg -quiet

        # The report_hw_axi_txn read_tx_reg returns the address and the vaule:  1025510  00000100
        # The character number 15 constains the tx ready bit of the register. Wait until 1
        while {[string index [report_hw_axi_txn read_tx_reg] 15] != 1} {
            # after 1
            run_hw_axi read_tx_reg -quiet
        }

        # Read the current character
        set character [string index $command $string_index]
        # Convert into ascii
        scan $character "%c" character_ascii_number
        # Convert ascii number into hexadecimal
        set character_hex [format %x $character_ascii_number]
        # Increment the index
        incr string_index

        # Write the character
        create_hw_axi_txn write_tx_reg [get_hw_axis hw_axi_1] -address $uart_addr_hex -data "$hex_header$padding$character_hex" -type write -force -quiet
        run_hw_axi write_tx_reg -quiet
        # after 1
    }

    run_hw_axi write_enter -quiet
    run_hw_axi write_enter -quiet
    run_hw_axi write_enter -quiet
    run_hw_axi write_enter -quiet

}
